#!/bin/bash
# google-earth-fonts-v0.2
# Marko Martinović (Marko-M), 2009
# Installation of Google Earth plus fix for ugly GUI fonts 

# "Press any key to continue" function.
function pause(){
   read -p "$*"
}

clear

# Am I root? Must be root to do what we need to do,
if [ "$(whoami)" != "root" ]
			then		
			echo "Please call this script with root privileges."
			echo
			pause "Press any key to EXIT"
			exit 0
		fi

echo -e "\n\033[1mWellcome to Google Earth + GUIFontsFix v0.3 installation script.\033[0m"

echo
echo -e "Google Earth for Linux comes with its own set of old Qt libraries. To match your distro look and feel it is necessary to link Google Earth with Qt libraries provided by your distribution. This script installs Google Earth if it's not already installed and does job of linking libraries for you. Follow the instructions."
echo
pause "Press any key to begin"

echo

echo "Supported distributions are:"
echo
echo -e "  \033[1mUbuntu i686\033[0m"
echo -e "  \033[1mLinux Mint i686\033[0m"
echo
echo -e "Non supported distributions are:"
echo
echo -e "  \033[1mAll x86_64bit\033[0m"
echo
pause "Press any key to continue"
echo

# Which distro is this? With distro detection there's no standard amognst Linux distros. Ubuntu uses /etc/lsb-release file with discription of the distribution. Fedora uses /etc/fedora-release. Which architecture is this? Detected using "uname -m".

# Distro identify code
MACH=$(uname -m)
case "$MACH" in "i686")
	qtpath="/usr/lib/"
	if [ -f  /etc/lsb-release ] 
	then
		distString=$(cat /etc/lsb-release)
		if [[ $distString == *Ubuntu* ]] || [[ $distString == *Mint* ]]
		then			
			echo -e "\033[1mThis is i686 architecture supported distribution. Lets proceed...\033[0m"
			echo			
			pause "Press any key to continue"
			echo "Doing system files update check..."
			apt-get update
			echo	
			echo "Installing necessary packages..."
			echo "Installing Qt4 support..."
			apt-get -y install libqt4-core libqt4-gui libqt4-network libqt4-webkit qt4-qtconfig
		fi
	else			
		echo -e "\033[1mSorry. Your i686 distribution is not supported!\033[0m"
		pause "Press any key to EXIT"
		exit 0
	fi
	;;
	"x86_64")
	qtpath="/usr/lib32/"
	echo -e "\033[1mYour distribution architecture (x86_64) is NOT YET supported.\033[0m"
	pause "Press any key to continue"
	;;
	*)
	echo -e "\033[1mSorry. Support is planed only for i686 and x86_64 architectures!\033[0m"
	pause "Press any key to EXIT"
	exit 0
	;;
esac

# Is Google Earth already installed? If it is, skip this.
if [ -d /opt/google-earth ]
	then
		echo		
		echo "Google Earth is already installed. Continuing with GUIFontsFix."
	else		
		# Download and execution of installer
		echo
		echo -e "Google Earth is not installed! This script will now download Google Earth from Google server and start the installation."
		echo
		echo -e "\033[1mPlease install Google Earth in default install path location (/opt/google-earth) and DO NOT START GOOGLE EARTH AT THE END OF THE INSTALLATION PROCESS!\033[0m"
		echo
		echo -e "\033[1mI repeat: DO NOT START GOOGLE EARTH AT THE END OF THE INSTALLATION PROCESS!\033[0m"
		echo		
		pause "Press any key to continue"
		echo "Waiting for Google Earth installation to finish..."

		cd /tmp
		wget http://dl.google.com/earth/client/current/GoogleEarthLinux.bin && chmod +x GoogleEarthLinux.bin
		./GoogleEarthLinux.bin
		echo
		pause "Press any key to continue"
		rm GoogleEarthLinux.bin	
fi

echo
echo "Fixing Google Earth for Linux Qt4 libraries links..."

libqt_string=$(find ${qtpath} -type f \( -iname "libQtCore.so.*" ! -iname "*.ln" \) -exec basename {} \;)
qtver=${libqt_string##libQtCore.so.}

# Linking google-earth to systems Qt libraries
cd /opt/google-earth/
mv libQtCore.so.4 libQtCore.so.4.bak
mv libQtGui.so.4 libQtGui.so.4.bak
mv libQtNetwork.so.4 libQtNetwork.so.4.bak
mv libQtWebKit.so.4 libQtWebKit.so.4.bak
ln -s ${qtpath}libQtCore.so.$qtver libQtCore.so.4
ln -s ${qtpath}libQtGui.so.$qtver libQtGui.so.4
ln -s ${qtpath}libQtNetwork.so.$qtver libQtNetwork.so.4
ln -s ${qtpath}libQtWebKit.so.$qtver libQtWebKit.so.4

# Telling Google Earth where to look for Qt (fix for photos not shown after linking to system libraries)
echo -e "[Paths]\nDocumentation=/usr/share/doc\nLibraries=${qtpath}\nPlugins=${qtpath}qt4/plugins\nTranslations=/usr/share/qt4/translation" > /opt/google-earth/qt.conf

echo
echo "It all went well! You can start Google Earth from Internet subsection of your desktop menu. Also now you can use qtconfig-qt4 to configure the font settings."
echo
pause "Press any key to continue"
